@@ -24,9 +24,9 @@ import javax.portlet.RenderRequest;
 import javax.portlet.RenderResponse;
 import javax.portlet.UnavailableException;
 
-import jp.sf.pal.myfaces.portlet.MyFacesGenericPortlet;
+import org.seasar.teeda.core.portlet.FacesPortlet;
 
-public class BlogGenericPortlet extends MyFacesGenericPortlet
+public class BlogGenericPortlet extends FacesPortlet
 {
 
     /* (non-Javadoc)
